@@ -19,9 +19,7 @@ use XML::LibXML;
 use W3C::SOAP::Exception;
 use W3C::SOAP::Header;
 
-our $VERSION     = version->new('0.0.1');
-our @EXPORT_OK   = qw//;
-our %EXPORT_TAGS = ();
+our $VERSION     = version->new('0.0.2');
 
 has location => (
     is       => 'rw',
@@ -77,10 +75,10 @@ XML
         }
     }
     else {
-        W3C::SOAP::Exception::Input->throw(
+        W3C::SOAP::Exception::BadInput->throw(
             faultcode => 'UNKNOWN SOAP BODY',
             message   => "Don't know how to process ". (ref $body) ."\n",
-            error     => undef,
+            error     => '',
         );
     }
 
@@ -89,24 +87,16 @@ XML
 
 sub send {
     my ($self, $action, $xml) = @_;
-
-    my $url = $self->location;
+    my $content;
 
     try {
-        $self->mech->post(
-            $url,
-            'Content-Type'     => 'text/xml;charset=UTF-8',
-            'SOAPAction'       => qq{"$action"},
-            'Proxy-Connection' => 'Keep-Alive',
-            'Accept-Encoding'  => 'gzip, deflate',
-            Content            => $xml->toString,
-        );
+        $content = $self->_post($action, $xml);
     }
     catch ($e) {
         my $xml_error = eval { XML::LibXML->load_xml( string => $self->mech->res->content ) };
-        my $ns        = $self->_envelope_ns($xml_error);
 
         if ( $xml_error ) {
+            my $ns       = $self->_envelope_ns($xml_error);
             my ($code  ) = $xml_error->findnodes("//$ns\:Body/$ns\:Fault/faultcode");
             my ($string) = $xml_error->findnodes("//$ns\:Body/$ns\:Fault/faultstring");
             my ($actor ) = $xml_error->findnodes("//$ns\:Body/$ns\:Fault/faultactor");
@@ -127,7 +117,7 @@ sub send {
         }
     };
 
-    my $xml_responce = XML::LibXML->load_xml( string => $self->mech->content );
+    my $xml_responce = XML::LibXML->load_xml( string => $content );
     my $ns = $self->_envelope_ns($xml_responce);
 
     my ($node) = $xml_responce->findnodes("//$ns\:Body");
@@ -135,6 +125,22 @@ sub send {
     return $node;
 }
 
+sub _post {
+    my ($self, $action, $xml) = @_;
+    my $url = $self->location;
+
+    $self->mech->post(
+        $url,
+        'Content-Type'     => 'text/xml;charset=UTF-8',
+        'SOAPAction'       => qq{"$action"},
+        'Proxy-Connection' => 'Keep-Alive',
+        'Accept-Encoding'  => 'gzip, deflate',
+        Content            => $xml->toString,
+    );
+
+    return $self->mech->content;
+}
+
 sub _envelope_ns {
     my ($self, $xml) = @_;
     my %map
@@ -159,7 +165,7 @@ W3C::SOAP::Client - Client to talk SOAP to a server.
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::Client version 0.1.
+This documentation refers to W3C::SOAP::Client version 0.0.2.
 
 =head1 SYNOPSIS
 
