@@ -15,9 +15,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 
 
-our $VERSION     = version->new('0.0.1');
-our @EXPORT_OK   = qw//;
-our %EXPORT_TAGS = ();
+our $VERSION     = version->new('0.0.2');
 
 has node => (
     is       => 'rw',
@@ -90,7 +88,7 @@ W3C::SOAP::Document::Node - The super class for document nodes
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::Document::Node version 0.1.
+This documentation refers to W3C::SOAP::Document::Node version 0.0.2.
 
 =head1 SYNOPSIS
 
