@@ -16,10 +16,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 
 
-our $VERSION     = version->new('0.0.1');
-our @EXPORT_OK   = qw//;
-our %EXPORT_TAGS = ();
-#our @EXPORT      = qw//;
+our $VERSION     = version->new('0.0.2');
 
 has security => (
     is        => 'rw',
@@ -49,7 +46,7 @@ W3C::SOAP::Header - Object to create SOAP headers
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::Header version 0.1.
+This documentation refers to W3C::SOAP::Header version 0.0.2.
 
 =head1 SYNOPSIS
 
