@@ -19,10 +19,7 @@ use English qw/ -no_match_vars /;
 
 extends 'W3C::SOAP::Header::Security';
 
-our $VERSION     = version->new('0.0.1');
-our @EXPORT_OK   = qw//;
-our %EXPORT_TAGS = ();
-#our @EXPORT      = qw//;
+our $VERSION     = version->new('0.0.2');
 my $id = 0;
 
 has username => (
@@ -87,7 +84,7 @@ W3C::SOAP::Header::Security::Username - Creates a WS-Security User name object
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::Header::Security::Username version 0.1.
+This documentation refers to W3C::SOAP::Header::Security::Username version 0.0.2.
 
 =head1 SYNOPSIS
 
