@@ -17,10 +17,7 @@ use English qw/ -no_match_vars /;
 use W3C::SOAP::Utils qw/split_ns/;
 extends 'W3C::SOAP::Document::Node';
 
-our $VERSION     = version->new('0.0.1');
-our @EXPORT_OK   = qw//;
-our %EXPORT_TAGS = ();
-#our @EXPORT      = qw//;
+our $VERSION     = version->new('0.0.2');
 
 has message => (
     is         => 'rw',
@@ -61,7 +58,7 @@ W3C::SOAP::WSDL::Document::InOutPuts - <One-line description of module's purpose
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WSDL::Document::InOutPuts version 0.1.
+This documentation refers to W3C::SOAP::WSDL::Document::InOutPuts version 0.0.2.
 
 
 =head1 SYNOPSIS
