@@ -18,10 +18,7 @@ use W3C::SOAP::Utils qw/split_ns/;
 
 extends 'W3C::SOAP::Document::Node';
 
-our $VERSION     = version->new('0.0.1');
-our @EXPORT_OK   = qw//;
-our %EXPORT_TAGS = ();
-#our @EXPORT      = qw//;
+our $VERSION     = version->new('0.0.2');
 
 has element => (
     is         => 'rw',
@@ -79,7 +76,7 @@ W3C::SOAP::WSDL::Document::Message - <One-line description of module's purpose>
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WSDL::Document::Message version 0.1.
+This documentation refers to W3C::SOAP::WSDL::Document::Message version 0.0.2.
 
 
 =head1 SYNOPSIS
