@@ -22,10 +22,7 @@ use W3C::SOAP::Utils qw/split_ns/;
 use TryCatch;
 use DateTime::Format::Strptime qw/strptime/;
 
-our $VERSION     = version->new('0.0.1');
-our @EXPORT_OK   = qw//;
-our %EXPORT_TAGS = ();
-#our @EXPORT      = qw//;
+our $VERSION     = version->new('0.0.2');
 
 has xsd_ns => (
     is  => 'rw',
@@ -342,7 +339,7 @@ W3C::SOAP::XSD - The parent module to XSD modules
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD version 0.1.
+This documentation refers to W3C::SOAP::XSD version 0.0.2.
 
 =head1 SYNOPSIS
 
