@@ -18,10 +18,7 @@ use W3C::SOAP::Utils qw/split_ns/;
 
 extends 'W3C::SOAP::XSD::Document::Type';
 
-our $VERSION     = version->new('0.0.1');
-our @EXPORT_OK   = qw//;
-our %EXPORT_TAGS = ();
-#our @EXPORT      = qw//;
+our $VERSION     = version->new('0.0.2');
 
 has sequence => (
     is      => 'rw',
@@ -119,7 +116,7 @@ W3C::SOAP::XSD::Document::ComplexType - <One-line description of module's purpos
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD::Document::ComplexType version 0.1.
+This documentation refers to W3C::SOAP::XSD::Document::ComplexType version 0.0.2.
 
 
 =head1 SYNOPSIS
